<?php

if (!defined('ABSPATH')) {
    exit;
}

class TransactionCloudApi extends TransactionCloudHttp
{
    private const API_URL = 'https://api.transaction.cloud';
    private const BETA_URL = 'https://beta-api.transaction.cloud';
    private const SANDBOX_API_URL = 'https://sandbox-api.transaction.cloud';

    /** @var TransactionCloudAuth */
    protected $auth;

    /** @var string */
    private $apiUrl;

    /** @var array */
    protected $headers;

    function __construct()
    {
        $this->initHeaders();
        $this->useSandboxEnvironment();
    }

    /**
     * @param array $headers
     */
    public function addHeader($header)
    {
        $this->headers[] = $header;
    }

    /**
     * @return array
     */
    public function getHeaders()
    {
        $headers = array_merge($this->headers, [
            'Authorization: ' . $this->auth->getLogin() . ':' . $this->auth->getPassword()
        ]);

        return $headers;
    }

    /**
     * @param TransactionCloudAuth $auth
     */
    public function useAuth($auth)
    {
        $this->auth = $auth;
    }

    private function initHeaders()
    {
        $this->headers = [
            'Accept: application/json',
            'Content-Type: application/json'
        ];
    }

    public function useBetaEnvironment()
    {
        $this->apiUrl = self::BETA_URL;
    }

    public function useProductionEnvironment()
    {
        $this->apiUrl = self::API_URL;
    }

    public function useSandboxEnvironment()
    {
        $this->apiUrl = self::SANDBOX_API_URL;
    }

    /**
     * @param TransactionCloudConfigure
     *
     * @return TransactionCloudConfiguration|null
     */
    public function configure($config)
    {
        $url = $this->apiUrl . '/v1/woocommerce-configure';

        $data = $config->getConfigurationParams();

        try {
            $response = $this->doRequest($url, $data);
            $configuration = TransactionCloudConfiguration::make($response);
        } catch (\Exception $e) {
            $message = get_class($e) . ': ' . $e->getMessage();

            throw new Exception($message);
        }

        return $configuration;
    }

    /**
     * @param TransactionCloudCustomizeProduct
     *
     * @return TransactionCloudCustomizedProduct|null
     */
    public function customizeProduct($product)
    {
        $url = $this->apiUrl . '/v1/customize-product/' . $product->getProductId();

        $data = $product->getCustomizationParams();

        try {
            $response = $this->doRequest($url, $data);

            $customizedProduct = TransactionCloudCustomizedProduct::make($response);
        } catch (\Exception $e) {
            $message = get_class($e) . ': ' . $e->getMessage();

            throw new Exception($message);
        }

        return $customizedProduct;
    }

    /**
     * @param string $id
     *
     * @return TransactionCloudTransaction|null
     */
    public function getTransaction($id)
    {
        $url = $this->apiUrl . '/v1/transaction/' . $id;

        try {
            $response = $this->doRequest($url);

            $transaction = TransactionCloudTransaction::make($response);
        } catch (\Exception $e) {
            $message = get_class($e) . ': ' . $e->getMessage();

            throw new Exception($message);
        }

        return $transaction;
    }
}
