<?php

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @property string $id Unique identification for the transaction.
 * @property string $createDate Date of transaction creation.
 * @property string $email Email address used by the customer during purchase.
 * @property string|null $assignedEmail Email address used by the customer during website sign-up. It will be null until you set it with the "Assign email" endpoint.
 * @property string $productId Unique product identificator.
 * @property string $productName Name of the product
 * @property string $transactionType Type of product. Possible values: ONETIME|SUBSCRIPTION|VAULTED
 * @property string $transactionStatus Current status of the transaction. Possible values: TRANSACTION_STATUS_PENDING|TRANSACTION_STATUS_REFUNDED|ONE_TIME_PAYMENT_STATUS_PAID|SUBSCRIPTION_STATUS_ACTIVE|SUBSCRIPTION_STATUS_ACTIVE_TRIAL|SUBSCRIPTION_STATUS_CANCELLED|SUBSCRIPTION_STATUS_CANCELLED_PENDING|VAULTED_STATUS_ACTIVE|VAULTED_STATUS_INACTIVE
 * @property string $chargeFrequency Frequency of charges for recurring products. Possible values: UNKNOWN|DAILY|WEEKLY|MONTHLY|HALF_YEARLY|YEARLY
 * @property string $country Country where customer completed the payment.
 * @property string $lastCharge Date of the last successful payment.
 * @property string|null $payload Encrypted custom data passed before the checkout process. It's highly recommended to encrypt this data on your end.
 * @property string|null $whoCanceled Reason for cancellation in case of a canceled subscription or vaulted transaction. Possible values: TRANSACTION_CLOUD_ADMIN|VENDOR|CUSTOMER|NEXT_CHARGE|FAILED|PAYPAL
 * @property float $netPrice Net price
 * @property string $netPriceS Net price
 * @property float $netPriceInUSD Net price in USD
 * @property string $netPriceInUSDS Net price in USD
 * @property float $tax Tax amount.
 * @property string $taxS Tax amount.
 * @property string $currency Currency code of the transaction.
 * @property array $entries Transaction Entries
 * @property
 * @property
 */
class TransactionCloudTransaction extends TransactionCloudType
{
    public static function getAvailableProperties()
    {
        $availableProperties = [
            'assignedEmail',
            'chargeFrequency',
            'payload',
            'whoCanceled',
            'entries'
        ];

        return array_merge(
            $availableProperties,
            self::getRequiredProperties()
        );
    }

    public static function getRequiredProperties()
    {
        return [
            'id',
            'createDate',
            'email',
            'productId',
            'productName',
            'transactionType',
            'transactionStatus',
            'country',
            'lastCharge',
            'netPrice',
            'netPriceS',
            'netPriceInUSD',
            'netPriceInUSDS',
            'tax',
            'taxS',
            'currency'
        ];
    }
}
