<?php

class TransacionCloudUtil
{
    /**
     * Gets request header by its name. Returns default value
     * if header does not exist.
     *
     * @param string $key
     * @param mixed $default
     *
     * @return mixed
     */
    public static function getRequestHeader($key, $default = null)
    {
        $allHeaders = static::getRequestHeaders();

        if (isset($allHeaders[$key])) {
            return $allHeaders[$key];
        }

        return $default;
    }

    /**
     * Gets array of raw request headers.
     *
     * @return array
     */
    public static function getRawRequestHeaders()
    {
        if (!function_exists('apache_request_headers')) {
            $headers = [];
            foreach ($_SERVER as $key => $value) {
                if (substr($key, 0, 5) == 'HTTP_') {
                    $headers[str_replace(' ', '-', ucwords(str_replace('_', ' ', strtolower(substr($key, 5)))))] = $value;
                }
            }
            return $headers;
        }

        return apache_request_headers();
    }

    /**
     * Gets array of sanitized request headers.
     *
     * @return array
     */
    public static function getRequestHeaders()
    {
        $headers = [];

        foreach (static::getRawRequestHeaders() as $k => $v) {
            $headers[$k] = sanitize_text_field($v);
        }

        return $headers;
    }
}
